(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('doorgets-ng-truncate', ['exports', '@angular/core'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['doorgets-ng-truncate'] = {}, global.ng.core));
}(this, (function (exports, core) { 'use strict';

    var DoorgetsTruncateParser = /** @class */ (function () {
        function DoorgetsTruncateParser() {
            this.regexWord = /\s+/;
        }
        DoorgetsTruncateParser.prototype.parse = function (sentence, options) {
            if (typeof sentence !== 'string') {
                throw new Error('Parameter "sentence" must be string');
            }
            var originOptions = {
                limit: 100,
                trail: '...',
                position: 'right',
                words: false
            };
            var _option = typeof options === 'object'
                ? Object.assign(originOptions, options)
                : originOptions;
            if (sentence.length < _option.limit && !_option.words) {
                return sentence;
            }
            var _words = sentence.split(' ');
            if (_words.length < _option.limit && _option.words) {
                return sentence;
            }
            var splitTag = _option.words
                ? this.regexWord
                : '';
            var joinTag = _option.words
                ? ' '
                : '';
            var prefix = '';
            var suffix = '';
            var isMiddleOption = _option.position === 'center';
            var keys = sentence.split(splitTag);
            if (keys.length > _option.limit) {
                if (isMiddleOption) {
                    prefix = keys.slice(0, _option.limit % 2 == 0 ? _option.limit / 2 : _option.limit / 2 + 1).join(joinTag);
                    suffix = keys.reverse().slice(0, _option.limit / 2).reverse().join(joinTag);
                }
                else {
                    sentence = keys.slice(0, _option.limit).join(joinTag);
                }
            }
            switch (_option.position) {
                case 'left':
                    return _option.trail + sentence;
                case 'center':
                    return (prefix || suffix) ? prefix + _option.trail + suffix : sentence;
                default:
                    return sentence + _option.trail;
            }
        };
        return DoorgetsTruncateParser;
    }());

    var dgTruncateOptions = {
        limit: 100,
        trail: '...',
        position: 'right',
        words: false
    };
    var DgTruncateParser;
    var DoorgetsTruncateService = /** @class */ (function () {
        function DoorgetsTruncateService() {
            DgTruncateParser = DgTruncateParser || new DoorgetsTruncateParser();
            this._parser = DgTruncateParser;
        }
        DoorgetsTruncateService.prototype.truncate = function (sentence, options) {
            options = typeof options === 'object' ? options : {};
            var _options = Object.assign({}, dgTruncateOptions, options);
            return this._parser.parse(sentence, _options);
        };
        DoorgetsTruncateService.prototype.init = function (options) {
            if (typeof options === 'object') {
                dgTruncateOptions = Object.assign({}, dgTruncateOptions, options);
            }
        };
        DoorgetsTruncateService.prototype.getOptions = function () {
            return dgTruncateOptions;
        };
        return DoorgetsTruncateService;
    }());
    DoorgetsTruncateService.decorators = [
        { type: core.Injectable }
    ];
    DoorgetsTruncateService.ctorParameters = function () { return []; };

    var DoorgetsTruncatePipe = /** @class */ (function () {
        function DoorgetsTruncatePipe(_service) {
            this._service = _service;
        }
        DoorgetsTruncatePipe.prototype.transform = function (sentence, options) {
            return this._service.truncate(sentence, options);
        };
        return DoorgetsTruncatePipe;
    }());
    DoorgetsTruncatePipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'dgTruncate',
                    pure: true
                },] },
        { type: core.Injectable }
    ];
    DoorgetsTruncatePipe.ctorParameters = function () { return [
        { type: DoorgetsTruncateService }
    ]; };

    var DoorgetsTruncateDirective = /** @class */ (function () {
        function DoorgetsTruncateDirective(_render, _element, _service) {
            this._render = _render;
            this._element = _element;
            this._service = _service;
            this.currentOptions = {};
        }
        Object.defineProperty(DoorgetsTruncateDirective.prototype, "dgTruncate", {
            set: function (sentence) {
                if (typeof sentence === 'string') {
                    this.currentSentence = sentence;
                    this.doTruncate();
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(DoorgetsTruncateDirective.prototype, "dgTruncateOptions", {
            set: function (options) {
                this.currentOptions = typeof options === 'object'
                    ? options
                    : {};
            },
            enumerable: false,
            configurable: true
        });
        DoorgetsTruncateDirective.prototype.ngAfterViewChecked = function () {
            this.doTruncate();
        };
        DoorgetsTruncateDirective.prototype.doTruncate = function () {
            if (this.currentSentence) {
                this._element.nativeElement.textContent = ' ';
            }
            var childNodes = this._element.nativeElement.childNodes;
            for (var i = 0; i < childNodes.length; ++i) {
                var node = childNodes[i];
                if (node.nodeType === 3) {
                    this.checkNode(node);
                }
            }
        };
        DoorgetsTruncateDirective.prototype.checkNode = function (node) {
            if (!this.currentSentence) {
                this.currentSentence = this.getContent(node.textContent.trim(), node);
            }
            this.transform(this.currentSentence, node);
        };
        DoorgetsTruncateDirective.prototype.getContent = function (content, node) {
            if (content.length > 0) {
                if (content !== node.currentValue) {
                    this.currentSentence = content;
                    node.content = node.textContent;
                }
                else if (node.content) {
                    this.currentSentence = node.content.trim();
                    node.lastSentence = null;
                }
            }
            return this.currentSentence;
        };
        DoorgetsTruncateDirective.prototype.transform = function (currentSentence, node) {
            var params = this.dgTruncateOptions;
            if (this.alreadyTransformed(node, currentSentence, params)) {
                return;
            }
            this.lastOptions = params;
            var truncated = this._service.truncate(currentSentence, this.currentOptions);
            this.updateContent(truncated, currentSentence, node);
        };
        DoorgetsTruncateDirective.prototype.setNodeKey = function (truncated, currentSentence, node) {
            if (truncated !== currentSentence) {
                node.lastSentence = currentSentence;
            }
        };
        DoorgetsTruncateDirective.prototype.setNodeContent = function (node) {
            if (!node.content) {
                node.content = node.textContent;
            }
        };
        DoorgetsTruncateDirective.prototype.updateContent = function (truncated, currentSentence, node) {
            this.setNodeKey(truncated, currentSentence, node);
            this.setNodeContent(node);
            node.currentValue = truncated
                ? truncated
                : (node.content || currentSentence);
            node.textContent = this.currentSentence
                ? node.currentValue
                : node.content.replace(currentSentence, node.currentValue);
        };
        DoorgetsTruncateDirective.prototype.alreadyTransformed = function (node, currentSentence, options) {
            return node.lastSentence === currentSentence && this.lastOptions === options;
        };
        return DoorgetsTruncateDirective;
    }());
    DoorgetsTruncateDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[dgTruncate]'
                },] }
    ];
    DoorgetsTruncateDirective.ctorParameters = function () { return [
        { type: core.Renderer2 },
        { type: core.ElementRef },
        { type: DoorgetsTruncateService }
    ]; };
    DoorgetsTruncateDirective.propDecorators = {
        dgTruncate: [{ type: core.Input }],
        dgTruncateOptions: [{ type: core.Input }]
    };

    var DoorgetsTruncateModule = /** @class */ (function () {
        function DoorgetsTruncateModule() {
        }
        return DoorgetsTruncateModule;
    }());
    DoorgetsTruncateModule.decorators = [
        { type: core.NgModule, args: [{
                    providers: [DoorgetsTruncateService],
                    declarations: [DoorgetsTruncatePipe, DoorgetsTruncateDirective],
                    exports: [DoorgetsTruncatePipe, DoorgetsTruncateDirective]
                },] }
    ];

    /*
     * Public API Surface of doorgets-ng-truncate
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.DoorgetsTruncateDirective = DoorgetsTruncateDirective;
    exports.DoorgetsTruncateModule = DoorgetsTruncateModule;
    exports.DoorgetsTruncateParser = DoorgetsTruncateParser;
    exports.DoorgetsTruncatePipe = DoorgetsTruncatePipe;
    exports.DoorgetsTruncateService = DoorgetsTruncateService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=doorgets-ng-truncate.umd.js.map
